@@ -76,36 +76,31 @@ class Chrome():
         os.makedirs(log_dir, exist_ok=True)
         log_file_path = os.path.join(log_dir, f"mitmdump_{listen_port}.log")
 
-        try:
-            # 打开日志文件（追加模式）
-            with open(log_file_path, "ab") as log_file:
-                process = subprocess.Popen([
-                    "mitmdump",
-                    "-s", script_path,
-                    "--listen-port", str(listen_port),
-                    "--mode", f"upstream:{upstream_url}",
-                    "--upstream-auth", upstream_auth,
-                    base64_str,
-                ], stdout=log_file, stderr=subprocess.STDOUT)  # 合并stdout和stderr到同一文件
+        # 打开日志文件（追加模式）
+        with open(log_file_path, "ab") as log_file:
+            process = subprocess.Popen([
+                "mitmdump",
+                "-s", script_path,
+                "--listen-port", str(listen_port),
+                "--mode", f"upstream:{upstream_url}",
+                "--upstream-auth", upstream_auth,
+                base64_str,
+            ], stdout=log_file, stderr=subprocess.STDOUT)  # 合并stdout和stderr到同一文件
 
-                # 等待几秒，看是否异常退出
-                time.sleep(3)
+            # 等待几秒，看是否异常退出
+            time.sleep(3)
 
-                # 检查是否还活着
-                if process.poll() is None:
-                    print(f"✅ mitmdump 启动成功，进程ID: {process.pid}")
-                    print(f"日志文件: {os.path.abspath(log_file_path)}")
-                else:
-                    # 异常退出，读取日志文件内容
-                    print("❌ mitmdump 启动失败，错误日志:")
-                    with open(log_file_path, "rb") as f:
-                        print(f.read().decode('utf-8', errors='replace'))
+            # 检查是否还活着
+            if process.poll() is None:
+                print(f"✅ mitmdump 启动成功，进程ID: {process.pid}")
+                print(f"日志文件: {os.path.abspath(log_file_path)}")
+            else:
+                # 异常退出，读取日志文件内容
+                print("❌ mitmdump 启动失败，错误日志:")
+                with open(log_file_path, "rb") as f:
+                    print(f.read().decode('utf-8', errors='replace'))
 
-                    return None
-
-        except Exception as e:
-            print(f"启动 mitmdump 时发生异常: {str(e)}")
-            return None
+                return None
 
         return process
 
@@ -129,10 +124,10 @@ class Chrome():
         ip = socks_data.get("ip")
         port = socks_data.get("port")
         uuid:str = socks_data.get("uuid")
-        
-        if "uuid" not in socks_data:            
+
+        if "uuid" not in socks_data:
             raise IpException("缺少 uuid")
-        
+
         vmess_obj = {
             "add": ip, # 服务器域名或 IP
             "port": port, # 端口，字符串或整数
@@ -144,14 +139,10 @@ class Chrome():
         b = base64.b64encode(j.encode('utf-8')).decode('utf-8')
         # 创建 VMess 链接
         vmess_link = f"vmess://{b}"
-        
-        try:
-            v2ray = V2RayProxy(vmess_link,listen_port)
-            return v2ray
-        except Exception as e:
-            print(f"启动 V2Ray 时发生异常: {str(e)}")            
-        return None
-    
+
+        v2ray = V2RayProxy(vmess_link,listen_port)
+        return v2ray
+
     def start_driver(self, data, listen_port, user_data_dir):
         '''
         @Desc    : 启动驱动
