@@ -76,7 +76,7 @@ class V2RayCore:
         # https://oss-rpa.oss-cn-shenzhen.aliyuncs.com/uploads/v2fly/v2ray-linux-64.zip
         
         # self.release_tag_url = os.environ.get("V2RAY_RELASE_TAG_URL") or "https://github.com/v2fly/v2ray-core/releases/download/v5.38.0"
-        self.release_tag_url = os.environ.get("V2RAY_RELASE_TAG_URL") or "https://oss-rpa.oss-cn-shenzhen.aliyuncs.com/uploads/v2fly"
+        self.release_tag_url = os.environ.get("V2RAY_RELASE_TAG_URL") or "http://oss-rpa.oss-cn-shenzhen.aliyuncs.com/uploads/v2fly"
         if os.environ.get("V2RAY_EXECUTABLE_DIR"):
             self.executable_dir = os.environ["V2RAY_EXECUTABLE_DIR"]
             self.executable = os.path.join(self.executable_dir, "v2ray.exe" if os.name == "nt" else "v2ray")
